%define pypi_name celery

# missing python-sphinx_celery (for the moment)
%bcond_with docs

# comment out if not pre release
#global prel rc3

Name:           python-celery
Version:        5.3.6
Release:        %mkrel 3
BuildArch:      noarch
Group:          Development/Python
License:        BSD
URL:            https://celeryproject.org/
Source0:        %{pypi_source}
Patch0:         0001-fix-reqs.patch
#
# Security patches
# P100 -> ...
#
Summary:        Distributed Task Queue
BuildRequires:  git-core

%description
An open source asynchronous task queue/job queue based on
distributed message passing. It is focused on real-time
operation, but supports scheduling as well.

The execution units, called tasks, are executed concurrently
on one or more worker nodes using multiprocessing, Eventlet
or gevent. Tasks can execute asynchronously (in the background)
or synchronously (wait until ready).

Celery is used in production systems to process millions of
tasks a day.

Celery is written in Python, but the protocol can be implemented
in any language. It can also operate with other languages using
web hooks.

The recommended message broker is RabbitMQ, but limited support
for Redis, Beanstalk, MongoDB, CouchDB and databases
(using SQLAlchemy or the Django ORM) is also available.

%if %{with docs}
%package doc
Summary: Documentation for python-celery
Group:   Development/Python
BuildRequires: texlive
BuildRequires: texlive-dist
BuildRequires:  python3-devel

%description doc
Documentation for python-celery.
%endif

%package -n python3-celery
Summary:        Distributed Task Queue
Group:          Development/Python
%{?python_provide:%python_provide python3-celery}
BuildRequires:  python3-devel
BuildRequires:  python3-rpm-macros
BuildRequires:  python3-setuptools


%description -n python3-celery
An open source asynchronous task queue/job queue based on
distributed message passing. It is focused on real-time
operation, but supports scheduling as well.

The execution units, called tasks, are executed concurrently
on one or more worker nodes using multiprocessing, Eventlet
or gevent. Tasks can execute asynchronously (in the background)
or synchronously (wait until ready).

Celery is used in production systems to process millions of
tasks a day.

Celery is written in Python, but the protocol can be implemented
in any language. It can also operate with other languages using
web hooks.

The recommended message broker is RabbitMQ, but limited support
for Redis, Beanstalk, MongoDB, CouchDB and databases
(using SQLAlchemy or the Django ORM) is also available.


%prep
%autosetup -n celery-%{version}%{?prel} -p1 -S git


%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%if %{with docs}
pushd docs
%make_build html
popd
%endif

%install
%pyproject_install
%pyproject_save_files celery

pushd %{buildroot}%{_bindir}
ln -s celery celery-3
ln -s celery-3 celery-%{python3_version}
popd

%if %{with docs}
%files doc
%license LICENSE
%doc docs/.build/html/*
%endif

%files -n python3-celery -f %{pyproject_files} -f %{pyproject_files}
%license LICENSE
%doc README.rst TODO CONTRIBUTORS.txt examples
%{_bindir}/celery
%{_bindir}/celery-3*


%changelog
* Wed Jul 02 2025 umeabot <umeabot> 5.3.6-3.mga10
+ Revision: 2240001
- Mageia 10 Mass Rebuild

* Sun Mar 02 2025 wally <wally> 5.3.6-2.mga10
+ Revision: 2156840
- rebuild for python3.13

* Thu Feb 29 2024 papoteur <papoteur> 5.3.6-1.mga10
+ Revision: 2045767
- rebuild for python 3.12
- new version 5.3.6

* Wed Mar 23 2022 umeabot <umeabot> 5.2.3-3.mga9
+ Revision: 1823970
- Mageia 9 Mass Rebuild

* Sat Feb 26 2022 mrambo3501 <mrambo3501> 5.2.3-2.mga9
+ Revision: 1785611
- rebuild for python-3.10

* Sun Jan 16 2022 neoclust <neoclust> 5.2.3-1.mga9
+ Revision: 1768746
- Remove merged patch
- New version 5.2.3
- Add P100: Fixes CVE-2021-23727 (mga#29897)

* Fri Aug 27 2021 wally <wally> 5.1.2-1.mga9
+ Revision: 1743020
- new version 5.1.2

* Sat Jun 26 2021 wally <wally> 5.0.5-2.mga9
+ Revision: 1732514
- Rebuild for python 3.9

* Fri Jan 01 2021 luigiwalser <luigiwalser> 5.0.5-1.mga8
+ Revision: 1667781
- 5.0.5

* Mon Sep 14 2020 guillomovitch <guillomovitch> 4.4.7-1.mga8
+ Revision: 1626335
- new version 4.4.7

* Fri Oct 11 2019 tv <tv> 4.4.0-0.rc3.3.mga8
+ Revision: 1451728
- rebuild with python 3.8

* Tue Aug 20 2019 wally <wally> 4.4.0-0.rc3.2.mga8
+ Revision: 1430460
- drop python2 support

* Sun Aug 18 2019 wally <wally> 4.4.0-0.rc3.1.mga8
+ Revision: 1429690
- new version 4.4.0 rc3

* Sun Aug 18 2019 wally <wally> 4.3.0-1.mga8
+ Revision: 1429678
- new version 4.3.0
- update sphinx BR

* Sat Jan 12 2019 daviddavid <daviddavid> 4.2.1-1.mga7
+ Revision: 1355402
- add upstream patch to fix build with Python 3.7
- new version: 4.2.1
+ tmb <tmb>
- rebuild for python 3.7

* Thu Sep 20 2018 umeabot <umeabot> 4.0.2-5.mga7
+ Revision: 1288401
- Mageia 7 Mass Rebuild

* Sun Sep 10 2017 ngompa <ngompa> 4.0.2-4.mga7
+ Revision: 1152414
- Adapt for Mageia
- imported package python-celery


* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 4.0.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 4.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Jan 10 2017 Matthias Runge <mrunge@redhat.com> - 4.0.2-1
- upgrade to 4.0.x (rhbz#1400270, rhbz#1410864)

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 3.1.20-5
- Rebuild for Python 3.6

* Mon Nov 28 2016 Charalampos Stratakis <cstratak@redhat.com> - 3.1.20-4
- Remove obsolete Requires for python-uuid

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.1.20-3
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 3.1.20-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sun Jan 24 2016 Randy Barlow <rbarlow@redhat.com> - 3.1.20-1
- update to 3.1.20 (#1080882).

* Sat Jan 23 2016 Randy Barlow <rbarlow@redhat.com> - 3.1.19-1
- update to 3.1.19 (#1080882).
- Remove conditionals on Python 3 - always build for Python 3.
- Remove tests as they were disabled and don't pass anyway.
- Update to use the python2/3 naming conventions.
- Use the fancy new Python macros (#1300083).
- Add a -doc subpackage (#1223099).
- Use the license macro (#1223099).
- Remove dependency on importlib, since it is present in 2.7 and 3.5.

* Tue Dec 01 2015 Brian Bouterse <bbouters@redhat.com> - 3.1.11-1
- update to 3.1.11

* Tue Nov 10 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.1.9-5
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.1.9-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.1.9-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue May 27 2014 Kalev Lember <kalevlember@gmail.com> - 3.1.9-2
- Rebuilt for https://fedoraproject.org/wiki/Changes/Python_3.4

* Wed Feb 26 2014 Matthias Runge <mrunge@redhat.com> - 3.1.9-1
- update to 3.1.9 (rhbz#1055304)

* Wed Feb 26 2014 Matthias Runge <mrunge@redhat.com> - 3.1.7-4
- add runtime requirement pyzu (rhbz#1069774)
- remove runtime req. python-dateutil

* Fri Jan 10 2014 Matthias Runge <mrunge@redhat.com> - 3.1.7-3
- add runtime requirement python-setuptools (rhbz#1051176)

* Wed Jan 08 2014 Matthias Runge <mrunge@redhat.com> - 3.1.7-2
- require correct python-kombu-version

* Wed Jan 08 2014 Matthias Runge <mrunge@redhat.com> - 3.1.7-1
- update to 3.1.7 (rhbz#1034115)
- add more explicit requirement to python-billiard (rhbz#1028626)

* Mon Oct 14 2013 Matthias Runge <mrunge@redhat.com> - 3.0.24-1
- update to 3.0.24 (rhbz#1018596)

* Fri Sep 27 2013 Matthias Runge <mrunge@redhat.com> - 3.0.23-1
- update to 3.0.23 (rhbz#979595)

* Fri Sep 27 2013 Matthias Runge <mrunge@redhat.com> - 3.0.19-4
- add python-amqp to deps
- add requirement python-amqp
- fix requirements: python3-kombu, python3-pytz, python3-dateutil and billiard
- separate binaries for py3 and py (fixes rhbz#1000750)

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.19-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Apr 23 2013 Matthias Runge <mrunge@redhat.com> - 3.0.19-1
- update to celery-3.0.19 (rhbz#919560)

* Fri Feb 15 2013 Matthias Runge <mrunge@redhat.com> - 3.0.15-1
- update to celery-3.0.15 (rhbz#909919)

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.13-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jan 17 2013 Matthias Runge <mrunge@redhat.com> - 3.0.13-1
- update to upstream version 3.0.13 (rhbz#892923)

* Wed Nov 14 2012 Matthias Runge <mrunge@redhat.com> - 3.0.12-1
- update to upstream version 3.0.12

* Tue Oct 16 2012 Matthias Runge <mrunge@redhat.com> - 3.0.11-1
- update to upstream version 3.0.11

* Sun Aug 26 2012 Matthias Runge <mrunge@matthias-runge.de> - 3.0.7-1
- update to upstream version 3.0.7

* Thu Aug 23 2012 Matthias Runge <mrunge@matthias-runge.de> - 3.0.6-1
- update to upstream version 3.0.6

* Fri Aug 03 2012 Matthias Runge <mrunge@matthias-runge.de> - 3.0.5-1
- update to version 3.0.5
- enable python3 support

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.8-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.8-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Nov 28 2011 Andrew Colin Kissa <andrew@topdog.za.net> - 2.2.8-1
- Security FIX CELERYSA-0001

* Fri Jul 15 2011 Andrew Colin Kissa <andrew@topdog.za.net> - 2.2.7-3
- Fix rpmlint errors
- Fix dependencies

* Sat Jun 25 2011 Andrew Colin Kissa <andrew@topdog.za.net> 2.2.7-2
- Update for RHEL6

* Tue Jun 21 2011 Andrew Colin Kissa <andrew@topdog.za.net> 2.2.7-1
- Initial package
